@@ -4,14 +4,14 @@ This includes the CRS parsing, coordinate transforms and bounding box object.
 The bounding box can be calculated within Python, or read from a database result.
 """
 from __future__ import annotations
-import re
-from decimal import Decimal
-from dataclasses import dataclass, field
 
-from django.contrib.gis.geos import GEOSGeometry, Polygon
+import re
+from dataclasses import dataclass, field
+from decimal import Decimal
+from functools import lru_cache
 
 from django.contrib.gis.gdal import CoordTransform, SpatialReference
-from functools import lru_cache
+from django.contrib.gis.geos import GEOSGeometry, Polygon
 
 from gisserver.exceptions import ExternalParsingError, ExternalValueError
 
@@ -174,7 +174,7 @@ class CRS:
             try:
                 srid = int(crsid)
             except ValueError:
-                raise SyntaxError(
+                raise ExternalValueError(
                     f"CRS URI [{urn}] should contain a numeric SRID value."
                 ) from None
         elif authority == "OGC":
@@ -214,7 +214,7 @@ class CRS:
                 try:
                     srid = int(crsid)
                 except ValueError:
-                    raise SyntaxError(
+                    raise ExternalValueError(
                         f"CRS URI [{uri}] should contain a numeric SRID value."
                     ) from None
 
@@ -238,7 +238,7 @@ class CRS:
 
     @property
     def urn(self):
-        """Return The OGC URN corresponding to this CRS. """
+        """Return The OGC URN corresponding to this CRS."""
         return f"urn:{self.domain}:def:crs:{self.authority}:{self.version or ''}:{self.crsid}"
 
     def __str__(self):
