@@ -1,6 +1,7 @@
 """All parser logic to process <fes:...> and <gml:...> tags."""
 
-from .fes20 import Filter, function_registry as fes_function_registry
+from .fes20 import Filter
+from .fes20 import function_registry as fes_function_registry
 from .gml import parse_gml
 
 parse_fes = Filter.from_string
